==> zio-aws-macie2_2.13-5.17.115.1-sources.jar: zio/aws/macie2/model/GetFindingsFilterRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class GetFindingsFilterRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.GetFindingsFilterRequest = {
    import GetFindingsFilterRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.GetFindingsFilterRequest
      .builder()
      .id(__string.unwrap(id): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.GetFindingsFilterRequest.ReadOnly =
    zio.aws.macie2.model.GetFindingsFilterRequest.wrap(buildAwsValue())
}
object GetFindingsFilterRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.GetFindingsFilterRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.GetFindingsFilterRequest =
      zio.aws.macie2.model.GetFindingsFilterRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.GetFindingsFilterRequest
  ) extends zio.aws.macie2.model.GetFindingsFilterRequest.ReadOnly {
    override val id: __string =
      zio.aws.macie2.model.primitives.__string(impl.id())
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.GetFindingsFilterRequest
  ): zio.aws.macie2.model.GetFindingsFilterRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_2.13-6.20.42.1-sources.jar: zio/aws/macie2/model/GetFindingsFilterRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class GetFindingsFilterRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.GetFindingsFilterRequest = {
    import GetFindingsFilterRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.GetFindingsFilterRequest
      .builder()
      .id(id: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.GetFindingsFilterRequest.ReadOnly =
    zio.aws.macie2.model.GetFindingsFilterRequest.wrap(buildAwsValue())
}
object GetFindingsFilterRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.GetFindingsFilterRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.GetFindingsFilterRequest =
      zio.aws.macie2.model.GetFindingsFilterRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.GetFindingsFilterRequest
  ) extends zio.aws.macie2.model.GetFindingsFilterRequest.ReadOnly {
    override val id: __string = impl.id(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.GetFindingsFilterRequest
  ): zio.aws.macie2.model.GetFindingsFilterRequest.ReadOnly = new Wrapper(impl)
}
